@@ -29,11 +29,8 @@
 
 QString KirigamiPlugin::componentPath(const QString &fileName) const
 {
-    QString candidate;
-    QString candidatePath;
-
     foreach (const QString &style, m_stylesFallbackChain) {
-        candidate = QStringLiteral("styles/") + style + QLatin1Char('/') + fileName;
+        const QString candidate = QStringLiteral("styles/") + style + QLatin1Char('/') + fileName;
         if (QFile::exists(resolveFilePath(candidate))) {
             return resolveFileUrl(candidate);
         }
@@ -79,10 +76,11 @@ void KirigamiPlugin::registerTypes(const char *uri)
     qmlRegisterType(componentPath(QStringLiteral("ContextDrawer.qml")), uri, 1, 0, "ContextDrawer");
     qmlRegisterType(componentPath(QStringLiteral("GlobalDrawer.qml")), uri, 1, 0, "GlobalDrawer");
     qmlRegisterType(componentPath(QStringLiteral("Heading.qml")), uri, 1, 0, "Heading");
+    qmlRegisterType(componentPath(QStringLiteral("Separator.qml")), uri, 1, 0, "Separator");
 
     //The icon is "special: we have to use a wrapper class to QIcon on desktops
 #if !defined(Q_OS_ANDROID) && !defined(Q_OS_IOS)
-    if (m_stylesFallbackChain.first() == QStringLiteral("Desktop")) {
+    if (!m_stylesFallbackChain.isEmpty() && m_stylesFallbackChain.first() == QStringLiteral("Desktop")) {
         qmlRegisterType<DesktopIcon>(uri, 1, 0, "Icon");
     } else {
         qmlRegisterType(componentPath(QStringLiteral("Icon.qml")), uri, 1, 0, "Icon");
